@@ -1,3 +1,5 @@
+use core::fmt;
+
 use serde::{Deserialize, Serialize};
 
 #[derive(Serialize, Deserialize, Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
@@ -13,6 +15,18 @@ impl Default for NodeId {
     }
 }
 
+impl fmt::Display
+for NodeId
+{
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            NodeId::Unknown => write!(f, "unknown"),
+            NodeId::Client(id) => write!(f, "client({})", id),
+            NodeId::Server(server_id, node_id) => write!(f, "server(id={}, node={})", server_id, node_id),
+        }
+    }
+}
+
 impl NodeId {
     pub fn generate_client_id() -> NodeId {
         let client_id = fastrand::u64(..);
