@@ -1,18 +1,15 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
 use crate::time::ChainTimestamp;
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
-pub struct MetaDelayedUpload
-{
+pub struct MetaDelayedUpload {
     pub complete: bool,
     pub from: ChainTimestamp,
     pub to: ChainTimestamp,
 }
 
-impl std::fmt::Display
-for MetaDelayedUpload
-{
+impl std::fmt::Display for MetaDelayedUpload {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(f, "from-{}-to-{}", self.from, self.to)?;
         if self.complete {
@@ -22,4 +19,4 @@ for MetaDelayedUpload
         }
         Ok(())
     }
-}
\ No newline at end of file
+}
