@@ -1,16 +1,13 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
 use super::*;
 
 #[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
-pub struct MetaParent
-{
+pub struct MetaParent {
     pub vec: MetaCollection,
 }
 
-impl std::fmt::Display
-for MetaParent
-{
+impl std::fmt::Display for MetaParent {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(f, "{}", self.vec.parent_id)?;
         if self.vec.collection_id > 1 {
@@ -18,4 +15,4 @@ for MetaParent
         }
         Ok(())
     }
-}
\ No newline at end of file
+}
