@@ -7,6 +7,7 @@ use tokio::io::Error;
 use tokio::io::ErrorKind;
 use tokio::io::Result;
 use tracing::{debug, error, info, trace, warn};
+use bytes::Bytes;
 
 #[cfg(feature = "enable_local_fs")]
 use crate::chain::*;
@@ -170,6 +171,10 @@ impl RedoLog {
         Ok(self.log_file.load(&hash).await?)
     }
 
+    pub fn prime(&mut self, records: Vec<(AteHash, Option<Bytes>)>) {
+        self.log_file.prime(records);
+    }
+
     pub fn count(&self) -> usize {
         self.log_file.count()
     }
