@@ -4,6 +4,7 @@ use std::pin::Pin;
 use tracing::{debug, error, info, warn};
 
 use tokio::io::Result;
+use bytes::Bytes;
 
 use crate::error::*;
 use crate::event::*;
@@ -46,6 +47,8 @@ where
 
     fn count(&self) -> usize;
 
+    fn prime(&mut self, records: Vec<(AteHash, Option<Bytes>)>);
+
     fn size(&self) -> u64;
 
     fn index(&self) -> u32;
